//==============================================
//  MuseScore
//
//  Shamisen Notation plugin for MuseScore 4, Ver.4.1
// 
//  Copyright (C)2019-2023 Hiroshi Tachibana
//
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//==============================================
/*
2019.5.13 家庭式のニンベン用のtext1を追加した。
2019.5.15 休符の"0"を表示しないようにした。
2019.5.15 家庭式と文化譜を選択できるように改造した。
2019.5.20 調絃の入力方法を変更開始
2019.5.22  JapoScoreフォントを導入
2019.5.24 正常動作
2020.1.4 Ver.3.3に対応

メニューの１番目の家庭式（地唄式）の音符では、１の糸にニンベンを別途配置しています。フォントは太めの"ヒラギノ角ゴシック"に設定していますので、このフォントがない場合は、他のフォントに置き換えて表示されると思われます。
メニューの２番目の家庭式（地唄式）のJapoScoreフォントは、佐藤祈采さんのJapoScore用フォントで表示します。この場合、ニンベンも一つの文字となっています。
メニューの３番目の文化譜の場合には、五線譜の下に３線譜の空のパートを作成し（ウクレレ譜を３線に変更する等で）、その上に音符が並ぶように配置するのが適当です。
*/

import QtQuick 2.9
import QtQuick.Controls 1.5
import QtQuick.Layouts 1.3
import MuseScore 3.0
//import Qt.labs.settings 1.0

MuseScore {
  menuPath: "Plugins.Shamisen Notation" // 
  version: "4.10"
  description: qsTr("Shamisen Notation")
  pluginType: "dialog"
  title: "Shamisen Note"

  id: window
  width:330  // menu window size
  height:285

  ExclusiveGroup { id: exclusiveGroupKey }

  property var fontShami : "Hiragino Kaku Gothic Std" // "MS-PGothic"     ////       Shamisen Font Name
  property var fontShami2 : "JapoScoreStaff02"    // JapoScoreフォント     ////       Shamisen Font Name
  
  property var fileExist :true

  property var seplines

  property var ito1init :19 // 
  property var ito2init :14 //
  property var ito3init :12 //  

  property var val3noIto :62
  property var val2noIto :57
  property var val1noIto :50

  property var inxex3noIto :-1
  property var inxex2noIto :-1
  property var inxex1noIto :-1

  property var valCenterCInit : 60
  property var typeListInitNumber : 0
  property var fontSizeInit : 10
  property var yPositionInit : 2
  property var xPositionInit : 0
  property var partListInit : 0
  property var colorListInit : 0
  property var iBunka : 0

// Item positions in menu window
  property var itemX1 : 10
  property var itemX2 : 150
  property var itemY1 : 10
  property var itemDY : 28

    
  RowLayout {  //======================  家庭式、文化譜の選択 Katei or Bunkafu
    id: row1
    x :itemX1
    y :itemY1
    Label {
      text: "家庭Katei/文化Bunka"
    }
  }
  
  RowLayout {
    id: row1R
    x :itemX2
    y :itemY1-5
    ComboBox {
      currentIndex: typeListInitNumber
      implicitWidth: 170
      model: ListModel {
        id: typeList
        property var key
        ListElement { text: "家庭(地唄)Katei(Jiuta)"; iBunka: 0 }
        ListElement { text: " 同上  JapoScore font"; iBunka: 1 }
        ListElement { text: "文化譜Bunkafu"; iBunka: 2 }            //  2023.6.26文化譜を選択後、OKできなくなる
      }
      width: 170
      onCurrentIndexChanged: {
        console.debug(typeList.get(currentIndex).text + ", " + typeList.get(currentIndex).iBunka)
        typeList.key = typeList.get(currentIndex).iBunka
      }
    } // end ComboBox
  }

  
  RowLayout {  //======================  FONT SIZE
    id: row2
    x :itemX1
    y :itemY1+itemDY-5
    Label {
      text: "Font Size"
    }
  }
  
  RowLayout {
    id: row2R
    x :itemX2
    y :itemY1+itemDY-5
    SpinBox {
      id: valFontSize
      implicitWidth: 55
      decimals: 0
      minimumValue: 4
      maximumValue: 36
      value: fontSizeInit
    }
  }


  RowLayout {  //======================  Y POSITION
    id: row3
    x :itemX1
    y :itemY1+itemDY*5-5
    Label {
      text: "Y (縦) Position"
    }
  }

  RowLayout {
    id: row3R
    x :itemX2
    y :itemY1+itemDY*5-5
    SpinBox {
      id: valYPosition
      implicitWidth: 55
      decimals: 0
      minimumValue: -20
      maximumValue: 30
      value: yPositionInit
    }
  }


  
  RowLayout {  //======================  3の糸　細糸　高音
    id: row3J
    x :itemX1
    y :itemY1+itemDY*1.6
    Label {
      text: "3の糸 (MIDI num)"
    }
  }

  RowLayout {
    id: rowJ3R
    x :itemX2
    y :itemY1+itemDY*1.6
    ComboBox {
      currentIndex: ito3init
      implicitWidth: 150
      model: ListModel {
        id: val3noIto
        property var key
ListElement { text: "D5 74"; pName: 74 }  // 
ListElement { text: "C#5 73"; pName: 73 }
ListElement { text: "C5 72"; pName: 72 }
ListElement { text: "B4 71"; pName: 71 }
ListElement { text: "Bb4 70"; pName: 70 }
ListElement { text: "A4 69"; pName: 69 }
ListElement { text: "G#4 68"; pName: 68 }
ListElement { text: "G4 67"; pName: 67 }
ListElement { text: "F#4 66"; pName: 66 }
ListElement { text: "F4 65"; pName: 65 }
ListElement { text: "E4 64"; pName: 64 }
ListElement { text: "Eb4 63"; pName: 63 }
ListElement { text: "D4 62 壱越平調子"; pName: 62 }  // 7
ListElement { text: "C#4 61"; pName: 61 }
ListElement { text: "C4 60 三下り"; pName: 60 }
ListElement { text: "B3 59"; pName: 59 }
ListElement { text: "Bb3 58"; pName: 58 }
ListElement { text: "A3 57"; pName: 57 }
ListElement { text: "G#3 56"; pName: 56 }
ListElement { text: "G3 55 壱越平調子"; pName: 55 } // 14
ListElement { text: "F#3 54"; pName: 54 }
ListElement { text: "F3 53"; pName: 53 }
ListElement { text: "E3 52"; pName: 52 }
ListElement { text: "Eb3 51"; pName: 51 }
ListElement { text: "D3 50 壱越平調子"; pName: 50 } // 19番目
ListElement { text: "C#3 49"; pName: 49 }
ListElement { text: "C3 48"; pName: 48 }
ListElement { text: "B2 47"; pName: 47 }
ListElement { text: "Bb2 46"; pName: 46 }
ListElement { text: "A2 45"; pName: 45 }
ListElement { text: "G#2 44"; pName: 44 }
ListElement { text: "G2 43"; pName: 43 }
}
      width: 170
      onCurrentIndexChanged: {
        val3noIto.key = val3noIto.get(currentIndex).pName
      }
    }
  }

  RowLayout {  //======================  2の糸　中
    id: row2J
    x :itemX1
    y :itemY1+itemDY*2.65
    Label {
      text: "2の糸 (MIDI num)"
    }
  }

  RowLayout {
    id: rowJ2R
    x :itemX2
    y :itemY1+itemDY*2.65
    ComboBox {
      currentIndex: ito2init
      implicitWidth: 150
      model: ListModel {
        id: val2noIto
        property var key
ListElement { text: "A4 69"; pName: 69 }
ListElement { text: "G#4 68"; pName: 68 }
ListElement { text: "G4 67"; pName: 67 }
ListElement { text: "F#4 66"; pName: 66 }
ListElement { text: "F4 65"; pName: 65 }
ListElement { text: "E4 64"; pName: 64 }
ListElement { text: "Eb4 63"; pName: 63 }
ListElement { text: "D4 62 壱越平調子"; pName: 62 }
ListElement { text: "C#4 61"; pName: 61 }
ListElement { text: "C4 60"; pName: 60 }
ListElement { text: "B3 59"; pName: 59 }
ListElement { text: "Bb3 58"; pName: 58 }
ListElement { text: "A3 57 二上り"; pName: 57 }
ListElement { text: "G#3 56"; pName: 56 }
ListElement { text: "G3 55 壱越平調子"; pName: 55 }
ListElement { text: "F#3 54"; pName: 54 }
ListElement { text: "F3 53"; pName: 53 }
ListElement { text: "E3 52"; pName: 52 }
ListElement { text: "Eb3 51"; pName: 51 }
ListElement { text: "D3 50 壱越平調子"; pName: 50 } // 19番目
ListElement { text: "C#3 49"; pName: 49 }
ListElement { text: "C3 48"; pName: 48 }
ListElement { text: "B2 47"; pName: 47 }
ListElement { text: "Bb2 46"; pName: 46 }
ListElement { text: "A2 45"; pName: 45 }
ListElement { text: "G#2 44"; pName: 44 }
ListElement { text: "G2 43"; pName: 43 }
}
      width: 170
      onCurrentIndexChanged: {
        val2noIto.key = val2noIto.get(currentIndex).pName
      }
    }
  }

  RowLayout {  //======================  1の糸 低音　太い
    id: row1J
    x :itemX1
    y :itemY1+itemDY*3.7
    Label {
      text: "1の糸 (MIDI num)"
    }
  }

  RowLayout {
    id: rowJ1R
    x :itemX2
    y :itemY1+itemDY*3.7;
    ComboBox {
      currentIndex: ito1init
      implicitWidth: 150
      model: ListModel {
        id: val1noIto
        property var key
ListElement { text: "A4 69"; pName: 69 }
ListElement { text: "G#4 68"; pName: 68 }
ListElement { text: "G4 67"; pName: 67 }
ListElement { text: "F#4 66"; pName: 66 }
ListElement { text: "F4 65"; pName: 65 }
ListElement { text: "E4 64"; pName: 64 }
ListElement { text: "Eb4 63"; pName: 63 }
ListElement { text: "D4 62 壱越平調子"; pName: 62 }
ListElement { text: "C#4 61"; pName: 61 }
ListElement { text: "C4 60"; pName: 60 }
ListElement { text: "B3 59"; pName: 59 }
ListElement { text: "Bb3 58"; pName: 58 }
ListElement { text: "A3 57"; pName: 57 }
ListElement { text: "G#3 56"; pName: 56 }
ListElement { text: "G3 55 壱越平調子"; pName: 55 }
ListElement { text: "F#3 54"; pName: 54 }
ListElement { text: "F3 53"; pName: 53 }
ListElement { text: "E3 52"; pName: 52 }
ListElement { text: "Eb3 51"; pName: 51 }
ListElement { text: "D3 50 壱越平調子"; pName: 50 } // 19番目
ListElement { text: "C#3 49"; pName: 49 }
ListElement { text: "C3 48"; pName: 48 }
ListElement { text: "B2 47"; pName: 47 }
ListElement { text: "Bb2 46"; pName: 46 }
ListElement { text: "A2 45"; pName: 45 }
ListElement { text: "G#2 44"; pName: 44 }
ListElement { text: "G2 43"; pName: 43 }
}
      width: 170
      onCurrentIndexChanged: {
        val1noIto.key = val1noIto.get(currentIndex).pName
      }
    }
  }
  
    
  RowLayout {  //======================  X POSITION
    id: row4
    x :itemX1
    y :itemY1+itemDY*4+44
    Label {
      text: "X (横) Position"
    }
  }

  RowLayout {
    id: row4R
    x :itemX2
    y :itemY1+itemDY*4+44
    SpinBox {
      id: valXPosition
      implicitWidth: 55
      decimals: 1
      minimumValue: -5
      maximumValue: 5
      value: xPositionInit
      stepSize: 0.1
//      font.pointSize: fontSizeMenu
    }
  }


  RowLayout {  //======================  PART
    id: row5
    x :itemX1
    y :itemY1+itemDY*5+44
    Label {
      text: "Part"
    }
  }

  RowLayout {
    id: row5R
    x :itemX2
    y :itemY1+itemDY*5+44
    ComboBox {
        currentIndex: partListInit
        model: ListModel {
        id: partList
        property var key
        ListElement { text: "Part 1"; pName: 0 }
        ListElement { text: "Part 2"; pName: 1 }
        ListElement { text: "Part 3"; pName: 2 }
        ListElement { text: "Part 4"; pName: 3 }
      }
      width: 60
      onCurrentIndexChanged: {
        partList.key = partList.get(currentIndex).pName
      }
    } // end ComboBox
  }


  RowLayout {  //======================  COLOR
    id: row6
    x :itemX1
    y :itemY1+itemDY*6+44
    Label {
      text: "Color"
    }
  }

  RowLayout {
    id: row6R
    x :itemX2
    y :itemY1+itemDY*6+44
    ComboBox {
      currentIndex: colorListInit
      model: ListModel {
        id: colorList
        property var key
        ListElement { text: "Black"; cName: 0 }
        ListElement { text: "Red"; cName: 1 }
        ListElement { text: "Blue"; cName: 2 }
        ListElement { text: "Green"; cName: 3 }
        ListElement { text: "Purple"; cName: 4 }
        ListElement { text: "Gray"; cName: 5 }
      }
      width: 60
      onCurrentIndexChanged: {
        colorList.key = colorList.get(currentIndex).cName
      }
    } // end ComboBox
  }

  RowLayout { //============ Ver. No. ================
  id: rowVerNo
    x : 290
    y : 260
    Label {
      font.pointSize: 10
      text: "V"+version
    }
    }

  RowLayout {  //======================  CANCEL  /  OK
    id: row7
    x : 10
    y : 250
    Button {
      id: closeButton
      text: "Cancel"
      onClicked: { quit() }
    }
    Button {
      id: okButton
      text: "Ok"
      onClicked: {
        apply()
        quit()
      }
    }
  }


  function apply() {
    curScore.startCmd()
    applyToSelection()
    curScore.endCmd()
  }



  onRun: {
    if (typeof curScore === 'undefined') quit();
  } // end onRun


  function applyToSelection() {

    var cursor = curScore.newCursor();
    var startStaff;
    var endStaff;
    var endTick;
    var fullScore = false;

    var yPos = valYPosition.value+10 ;   //     Y offset= +10
    var xPos = valXPosition.value-0.5;

    var fontSize = valFontSize.value;

    var fontSizeTag="";//<font size=\""+fontSize+"\"/>";
    var fontFaceTag="";//<font face=\""+fontShami+"\"/>";

    var selPart=0;
//               RGB color  Black     , Red          , Blue         , Green       , Purple       , Gray
    var colorData=  [ "#000000" ,"#FF0000" ,"#0000FF" ,"#00FF00" ,"#C007C0" ,"#888888" ];
    var fontColor=colorData[colorList.key];


    cursor.rewind(1);  // rewind to start of selection
    if (!cursor.segment) { // no selection
      fullScore = true;
      startStaff = 0; // start with 1st staff
      endStaff  = curScore.nstaves - 1; // and end with last
    } else {
      startStaff = cursor.staffIdx;
      cursor.rewind(2); // rewind to end of selection
      if (cursor.tick == 0) {
        endTick = curScore.lastSegment.tick + 1;
      } else {
        endTick = cursor.tick;
      }
      endStaff   = cursor.staffIdx;
    }

    for (var staff = startStaff; staff <= endStaff; staff++) {
//      for (var voice = 0; voice < 4; voice++) {
        var voice=partList.key;
        var Ichi=0;

        cursor.rewind(1); // beginning of selection
        cursor.voice    = voice;
        cursor.staffIdx = staff;

        if (fullScore)  // no selection
          cursor.rewind(0); // beginning of score


        while (cursor.segment && (fullScore || cursor.tick < endTick)) {
         var text = newElement(Element.STAFF_TEXT);
         var text1 = newElement(Element.STAFF_TEXT);      //  ニンベン用のtext1の定義
         
          if (cursor.element && cursor.element.type == Element.CHORD) {
              var text = newElement(Element.STAFF_TEXT);
              var text1 = newElement(Element.STAFF_TEXT);
 text.placement = Placement.BELOW;
            text.autoplace = false;  // add 2019.9.18
text1.placement = Placement.BELOW;
            text1.autoplace = false;  // add 2019.9.18

// ######################## GRACE #####################################
            var graceChords = cursor.element.graceNotes;
            for (var i = 0; i < graceChords.length; i++) {

              var notes = graceChords[i].notes;
              nameChord(notes, text,text1, Ichi);

              text.offsetX =xPos -2.3 * (graceChords.length - i);      // X position of Grace note
              text1.offsetX =xPos -2.3 * (graceChords.length - i)-fontSize/12*0.7;  //  ニンベンの位置調整

              switch (voice) {
                case 0: text.offsetY = yPos-6.1;break;//-18.5; break;  //2023.6.25
                case 1: text.offsetY = yPos+2-6.1;break;//-18.5; break;
                case 2: text.offsetY = yPos+4-6.1;break;//-18.5; break;
                case 3: text.offsetY = yPos+6-6.1;break;//-18.5;  break;
              }
              switch (voice) {
                case 0: text1.offsetY = yPos-6.1;break;//-18.5; break;
                case 1: text1.offsetY = yPos+2-6.1;break;//-18.5; break;
                case 2: text1.offsetY = yPos+4-6.1;break;//-18.5; break;
                case 3: text1.offsetY = yPos+6-6.1;break;//-18.5;  break;
              }
              text.color= fontColor;
              text1.color= fontColor;
text.fontSize=fontSize*0.8;
text1.fontSize=fontSize*0.8;
              text.text= fontFaceTag + text.text;
              text1.text=fontFaceTag + text1.text;

 text.placement = Placement.BELOW;
 text.autoplace = false;  // add 2019.9.18
text1.placement = Placement.BELOW;
text1.autoplace = false;  // add 2019.9.18
              cursor.add(text);  //  装飾音符にノーテーションを表示
              if(typeList.key==0) cursor.add(text1); //   ニンベンを表示    ??? 2019.5.22に追加
			  text  = newElement(Element.STAFF_TEXT);     //  ?????????????????????
			  text1  = newElement(Element.STAFF_TEXT);     //  ?????????????????????
            } // end graceChorde
//####################################################################

            var notes = cursor.element.notes;
            nameChord(notes, text,text1, Ichi);
            switch (voice) {
              case 0: text.offsetY = yPos-6; break;
              case 1: text.offsetY = yPos+2-6; break;
              case 2: text.offsetY = yPos+4-6; break;
              case 3: text.offsetY = yPos+6-6; break;
            }
            switch (voice) {
              case 0: text1.offsetY = yPos-6; break;
              case 1: text1.offsetY = yPos+2-6; break;
              case 2: text1.offsetY = yPos+4-6; break;
              case 3: text1.offsetY = yPos+6-6; break;
            }
            text.color= fontColor;
            text1.color= fontColor;
            text.offsetX= xPos;
            text1.offsetX= xPos-fontSize/12*0.7; //  ニンベンの位置調整
					
 text.fontSize=fontSize;
text1.fontSize=fontSize;
text.autoplace = false;           // added 2023.6.25
text.placement = Placement.BELOW; // added 2023.6.25
text1.autoplace = false;           // added 2023.6.25
text1.placement = Placement.BELOW; // added 2023.6.25
			cursor.add(text); //   音符に表示

            if(typeList.key==0) cursor.add(text1); //   ニンベンを表示     2019.5.22にifを追加

            } else{ //  if (cursor.isRest)  { // if ( cursor.isRest() ){   //  休符に"0"を表示する。
            switch (voice) {
              case 0: text.offsetY = yPos-6; break;
              case 1: text.offsetY = yPos+2-6; break;
              case 2: text.offsetY = yPos+4-6; break;
              case 3: text.offsetY = yPos+6-6; break;
            }
            switch (voice) {
              case 0: text1.offsetY = yPos-6; break;
              case 1: text1.offsetY = yPos+2-6; break;
              case 2: text1.offsetY = yPos+4-6; break;
              case 3: text1.offsetY = yPos+6-6; break;
            }
            text.color= fontColor;
            text1.color= fontColor;
            text.offsetX= xPos;
            text1.offsetX= xPos;
					

           if(cursor.voice == voice) cursor.add(text); //   音符にノーテーションを表示 
           if(cursor.voice == voice && Ichi==1)  cursor.add(text1);


          } // end if CHORD
          cursor.next();
        } // end while segment
    } // end for staff
    quit();
  } // end onRun



  function nameChord (notes, text,text1, Ichi) {
    var noteBunkafu=["0","1","2","3","#","4","5","6","7","8","9","b","10","11","12","13","1#","14","15","16","17","18","19","1b","20","21","22"]
    var noteKatei3=["1","2","3","4","#4","5","6","7","8#","8","9","X","1·","2·","3·","4·","#4·","5·","6·","7·","8·","#8·","9·","X·","1:","2:","3:","4:","#4:","5:","6:","7:","8:","#8:","9:","X:"]
    var noteKatei2=["一","二","三","四","#四","五","六","七","八","#八","九","十","一・","二・","三・","四・","#四・","五・","六・","七・","八・","#八・","九・","十・"]
   if(typeList.key==0)   var noteKatei1=["一","二","三","四","#四","五","六","七","八","#八","九","十","一・","二・","三・","四・","#四・","五・","六・","七・","八・","#八・","九・","十・"]
   if(typeList.key==1)  var noteKatei1=   ["Ḁ","ḃ","Ḇ","ḉ","#ḉ","ḏ","Ḓ","ḕ","Ḙ","#Ḙ","Ḟ","ḡ","Ḥ","ḧ","Ḫ","ḉ·","#ḉ·","ḏ·","Ḓ·","ḕ·","Ḙ·","#Ḙ·","Ḟ·","ḡ·"]
    var noteNameS = [ "C","C♯","D","D♯","E","F","F♯","G","G♯","A","A♯","B" ]
    var noteNameF = [ "C","D♭","D","E♭","E","F","G♭","G","A♭","A","B♭","B" ]
    var JampuS= ["1","#1","2","#2","3","4","#4","5","#5","6","#6","7"]
    var JampuF= ["1","b2","2","b3","3","4","b5","5","b6","6","b7","7"]

    
    var fontSizeTag="";//<font size=\""+fontSize+"\"/>";
    var fontSizeTag1="";//<font size=\""+fontSize*1.0+"\"/>";
    if(typeList.key==0) var fontFaceTag="<font face=\""+fontShami+"\"/>";
    else if(typeList.key==1) var fontFaceTag="<font face=\""+fontShami2+"\"/>";
    else var fontFaceTag="<font face=\""+fontShami+"\"/>";
    var pitchFing;
    var index1noIto=-1;
    var index2noIto=-1;
    var index3noIto=-1;  // 使用しない糸は-1

    for (var i = notes.length-1; i >=0 ; i--) {  //                      和音の場合のループ。上の音から表示する =======================
      var sep =  "\n";   //  ","; // change to "\n" if you want them vertically
//  糸の割り振り
      if( notes[i].pitch >= val3noIto.key) {  //  3の糸以上の高い音の場合
        index3noIto=notes[i].pitch-val3noIto.key;
      }
      if(notes[i].pitch <val3noIto.key && notes[i].pitch >= val2noIto.key) { //３の糸より低く、２の糸以上の音の場合
        index2noIto=notes[i].pitch-val2noIto.key;
      }
      if(notes[i].pitch < val2noIto.key && notes[i].pitch >= val1noIto.key){ // 2の糸より低く、１の糸以上の音の場合
        index1noIto=notes[i].pitch-val1noIto.key;
      }
console.log( index1noIto);

        if(notes[i].tieBack == null) {  // タイの後ろ側ではないとき===================================
          text.text = fontFaceTag + text.text;
          if(typeList.key==0 && index1noIto != -1) text1.text = fontFaceTag + text1.text+" "+sep+" "+sep+"亻";   //       一の糸のニンベン
        }else{
//          text.text=" ";//sep+sep;
          text  = newElement(Element.STAFF_TEXT); 
          text1  = newElement(Element.STAFF_TEXT); 
//          text1.text=" ";//sep+sep;
        } // end for tieBack
    }  // 和音のループ終わり

   if(typeList.key == 0){  //     家庭式（地唄式）Katei, Jiuta
      if(index3noIto == -1) text.text =  text.text+" "+sep;   //    三の糸  高音
      else {
        if(index3noIto>=12) text.text = text.text+qsTr(noteKatei3[index3noIto])+sep;
        else text.text = text.text+" "+qsTr(noteKatei3[index3noIto])+sep;
      }
      if(index2noIto == -1) text.text = text.text+" "+sep;   //   二の糸　中
      else{
      if(index2noIto>=12) text.text = text.text+qsTr(noteKatei2[index2noIto])+sep;
        else text.text = text.text+" "+qsTr(noteKatei2[index2noIto])+sep;
     }
      if(index1noIto == -1) text.text =  text.text+" "; //     //  一の糸　低音
      else{
        if(index1noIto>=12) text.text = text.text+qsTr(noteKatei1[index1noIto])+sep;
        else text.text = text.text+" "+qsTr(noteKatei1[index1noIto])+sep;
     }
     if(index1noIto != -1) Ichi=1;

    } else if(typeList.key ==1){    //          JapoScore  家庭式（地唄式）Katei, Jiuta
      if(index3noIto == -1) text.text =  text.text+" "+sep;   //    三の糸  高音
      else {
        if(index3noIto>=12) text.text = text.text+qsTr(noteKatei3[index3noIto])+sep;
        else text.text = text.text+" "+qsTr(noteKatei3[index3noIto])+sep;
      }
      if(index2noIto == -1) text.text = text.text+" "+sep;   //   二の糸　中
      else{
      if(index2noIto>=12) text.text = text.text+qsTr(noteKatei2[index2noIto])+sep;
        else text.text = text.text+" "+qsTr(noteKatei2[index2noIto])+sep;
     }
      if(index1noIto == -1) text.text =  text.text+" "; //     //  一の糸　低音
      else{
        if(index1noIto>=12) text.text = text.text    +qsTr(noteKatei1[index1noIto])+sep;
        else                text.text = text.text+" "+qsTr(noteKatei1[index1noIto])+sep;
     }
     if(index1noIto != -1) Ichi=1; 


    } else if(typeList.key ==2){    //            文化譜 Bunkafu
      if(index3noIto == -1) text.text =  text.text+" "+sep;   //    三の糸  高音
      else {
        if(index3noIto>=12) text.text = text.text+qsTr(noteBunkafu[index3noIto])+sep;
        else text.text = text.text+" "+qsTr(noteBunkafu[index3noIto])+sep;
      }
      if(index2noIto == -1) text.text = text.text+" "+sep;   //   二の糸　中
      else{
      if(index2noIto>=12) text.text = text.text+qsTr(noteBunkafu[index2noIto])+sep;
        else text.text = text.text+" "+qsTr(noteBunkafu[index2noIto])+sep;
     }
      if(index1noIto == -1) text.text =  text.text+" "; //     //  一の糸　低音
      else{
        if(index1noIto>=12) text.text = text.text    +qsTr(noteBunkafu[index1noIto])+sep;
        else                text.text = text.text+" "+qsTr(noteBunkafu[index1noIto])+sep;
     }

    }
  } // end function
} // end MuseScore
